@@ -59,9 +59,7 @@ class Agent(Protocol):
     capture_condition: asyncio.Condition
     capture_active: bool
 
-    async def asend(
-        self: "Agent", actor: "Actor", message: messages.FromAgentMessage
-    ) -> None:
+    async def asend(self: "Agent", actor: "Actor", message: messages.FromAgentMessage) -> None:
         """A function to send a message to the agent. This is used to send messages
         to the agent from the actor."""
 
@@ -135,11 +133,6 @@ class Actor(Protocol):
         """
         ...
 
-    async def arun(self) -> asyncio.Task[None]:
-        """Run the actor. This method will run the actor and return None.
-        This is used to run the actor"""
-        ...
-
     async def acheck_assignation(
         self: Self,
         assignation_id: str,
