@@ -27,6 +27,7 @@ from .errors import (
     AgentWasKicked,
     AgentIsAlreadyBusy,
     AgentWasBlocked,
+    KickError,
 )
 from pydantic import BaseModel
 
@@ -44,7 +45,9 @@ logger = logging.getLogger(__name__)
 
 async def token_loader() -> str:
     """Dummy token loader function"""
-    raise NotImplementedError("Websocket transport does need a defined token_loader on Connection")
+    raise NotImplementedError(
+        "Websocket transport does need a defined token_loader on Connection"
+    )
 
 
 KICK_CODE = 3001
@@ -115,7 +118,11 @@ class WebsocketAgentTransport(AgentTransport):
                     token = await self.token_loader()
                     async with websockets.connect(
                         f"{self.endpoint_url}",
-                        ssl=(self.ssl_context if self.endpoint_url.startswith("wss") else None),
+                        ssl=(
+                            self.ssl_context
+                            if self.endpoint_url.startswith("wss")
+                            else None
+                        ),
                     ) as client:
                         retry = 0
                         logger.info("Agent on Websockets connected")
@@ -131,7 +138,9 @@ class WebsocketAgentTransport(AgentTransport):
                         self._healthy = True
 
                         async for message in client:
-                            assert isinstance(message, str), "Message should be a string"
+                            assert isinstance(message, str), (
+                                "Message should be a string"
+                            )
                             payload = InMessagePayload(message=json.loads(message))
                             logger.debug(f"<<<< {payload}")
 
@@ -139,7 +148,13 @@ class WebsocketAgentTransport(AgentTransport):
                                 await self.asend(messages.HeartbeatEvent())
                             elif isinstance(payload.message, messages.Bounce):
                                 print("Received Bounce message")
-                                raise BounceError("Was bounced. Debug call to reconnect")
+                                raise BounceError(
+                                    "Was bounced. Debug call to reconnect"
+                                )
+                            elif isinstance(payload.message, messages.Kick):
+                                raise KickError(
+                                    f"Agent was kicked by the server: {payload.message.reason or 'No reason provided'}"
+                                )
                             else:
                                 yield payload.message
 
@@ -154,11 +169,19 @@ class WebsocketAgentTransport(AgentTransport):
                         exc_info=True,
                     )
                     reload_token = True
-                    raise CorrectableConnectionFail("Received an InvalidHandshake") from e
+                    raise CorrectableConnectionFail(
+                        "Received an InvalidHandshake"
+                    ) from e
 
                 except BounceError as e:
                     logger.warning("Received Bounce message", exc_info=True)
-                    raise CorrectableConnectionFail("Was bounced. Debug call to reconnect") from e
+                    raise CorrectableConnectionFail(
+                        "Was bounced. Debug call to reconnect"
+                    ) from e
+
+                except KickError as e:
+                    logger.warning("Agent was kicked by the server", exc_info=True)
+                    raise DefiniteConnectionFail("Agent was kicked") from e
 
                 except ConnectionClosedError as e:
                     logger.warning("Websocket was closed", exc_info=True)
@@ -196,7 +219,9 @@ class WebsocketAgentTransport(AgentTransport):
                     logger.error("Max retries reached. Giving up")
                     raise DefiniteConnectionFail("Exceeded Number of Retries")
 
-                logger.info(f"Waiting for some time before retrying: {self.time_between_retries}")
+                logger.info(
+                    f"Waiting for some time before retrying: {self.time_between_retries}"
+                )
                 await asyncio.sleep(self.time_between_retries)
                 logger.info("Retrying to connect")
                 retry += 1
