@@ -139,6 +139,12 @@ def is_float(cls: Any) -> bool:  # noqa: ANN401
     return False
 
 
+def is_none_type(cls: Any) -> bool:  # noqa: ANN401
+    """Check if a class is NoneType"""
+
+    return cls is types.NoneType
+
+
 def is_generator_type(cls: Any) -> bool:  # noqa: ANN401
     """Check if a class is a generator type"""
     if get_origin(cls) in (
@@ -289,7 +295,9 @@ def convert_object_to_port(
 
     if is_list(cls):
         value_cls = get_list_value_cls(cls)
-        child = convert_object_to_port(cls=value_cls, registry=registry, nullable=False, key="...")
+        child = convert_object_to_port(
+            cls=value_cls, registry=registry, nullable=False, key="..."
+        )
         return PortInput(
             kind=PortKind.LIST,
             assignWidget=assign_widget,
@@ -329,7 +337,9 @@ def convert_object_to_port(
 
     if is_dict(cls):
         value_cls = get_dict_value_cls(cls)
-        child = convert_object_to_port(cls=value_cls, registry=registry, nullable=False, key="...")
+        child = convert_object_to_port(
+            cls=value_cls, registry=registry, nullable=False, key="..."
+        )
         return PortInput(
             kind=PortKind.DICT,
             assignWidget=assign_widget,
@@ -495,7 +505,9 @@ def prepare_definition(
 
     assert structure_registry is not None, "You need to pass a StructureRegistry"
 
-    is_generator = inspect.isasyncgenfunction(function) or inspect.isgeneratorfunction(function)
+    is_generator = inspect.isasyncgenfunction(function) or inspect.isgeneratorfunction(
+        function
+    )
 
     sig = inspect.signature(function)
     widgets = widgets or {}
@@ -535,7 +547,9 @@ def prepare_definition(
 
     function_ins_annotation = sig.parameters
 
-    doc_param_description_map = {param.arg_name: param.description for param in docstring.params}
+    doc_param_description_map = {
+        param.arg_name: param.description for param in docstring.params
+    }
     doc_param_label_map: Dict[str, str] = {
         param.arg_name: param.arg_name for param in docstring.params
     }
@@ -555,7 +569,9 @@ def prepare_definition(
         )
     elif docstring.returns:
         doc_param_description_map.update({"return0": docstring.returns.description})
-        doc_param_label_map.update({"return0": docstring.returns.return_name or "return0"})
+        doc_param_label_map.update(
+            {"return0": docstring.returns.return_name or "return0"}
+        )
 
     if port_label_map:
         doc_param_label_map.update(port_label_map)
@@ -631,7 +647,7 @@ def prepare_definition(
 
     else:
         # We are dealing with a non tuple return
-        if function_outs_annotation is None:
+        if function_outs_annotation is None or is_none_type(function_outs_annotation):
             pass
 
         else:
@@ -681,7 +697,9 @@ def prepare_definition(
         action_name = name
 
     elif docstring.long_description:
-        action_name = docstring.short_description or snake_to_title_case(function.__name__)
+        action_name = docstring.short_description or snake_to_title_case(
+            function.__name__
+        )
         description = description or docstring.long_description
 
     else:
