@@ -23,8 +23,8 @@ from rekuest_next.api.schema import (
     AssignInput,
     HookInput,
     Action,
-    find,
-    afind,
+    find as find_node,
+    afind as afind_node,
     Reservation,
     Implementation,
 )
@@ -36,6 +36,11 @@ from rekuest_next.structures.registry import (
 )
 from rekuest_next.structures.default import get_default_structure_registry
 from rekuest_next.structures.serialization.postman import aexpand_returns, ashrink_args
+from typing import TYPE_CHECKING
+
+
+if TYPE_CHECKING:
+    from rekuest_next.declare import DeclaredFunction, DeclaredProtocol
 
 
 __all__ = [
@@ -44,6 +49,40 @@ __all__ = [
 ]
 
 
+async def afind(
+    action_implementation_res: Union[
+        ID, Action, Implementation, Reservation, "DeclaredFunction", "DeclaredProtocol"
+    ],
+) -> Action:
+    from rekuest_next.declare import DeclaredFunction, DeclaredProtocol
+
+    """Find and return the assignation generator"""
+    if isinstance(action_implementation_res, Action):
+        return action_implementation_res
+
+    if isinstance(action_implementation_res, (ID, str)):
+        action_implementation_res = await afind_node(action_implementation_res)
+        return action_implementation_res
+
+    if isinstance(action_implementation_res, (DeclaredFunction, DeclaredProtocol)):
+        action_implementation_res = await afind_node(
+            matching=action_implementation_res.to_dependency_input()
+        )
+        return action_implementation_res
+
+    raise ValueError(
+        "action_implementation_res must be an ID, Action, Implementation, Reservation, DeclaredFunction or DeclaredProtocol"
+    )
+
+
+def find(
+    action_implementation_res: Union[
+        ID, Action, Implementation, Reservation, "DeclaredFunction", "DeclaredProtocol"
+    ],
+) -> Action:
+    return unkoil(afind, action_implementation_res)
+
+
 def ensure_return_as_tuple(value: Any) -> tuple[Any]:  # noqa: ANN401
     """Ensure that the value is a list."""
     if not value:
@@ -62,6 +101,7 @@ async def acall_raw(
     reference: Optional[str] = None,
     hooks: Optional[List[HookInput]] = None,
     cached: bool = False,
+    capture: bool = False,
     assign_timeout: Optional[float] = None,
     timeout_is_recoverable: bool = False,
     log: bool = False,
@@ -89,6 +129,7 @@ async def acall_raw(
         reference=reference,
         hooks=tuple(hooks or []),
         cached=cached,
+        capture=capture,
         parent=ID.validate(parent.assignation) if parent else None,
         log=log,
         isHook=False,
@@ -117,6 +158,7 @@ async def aiterate_raw(
     reference: Optional[str] = None,
     hooks: Optional[List[HookInput]] = None,
     cached: bool = False,
+    capture: bool = False,
     assign_timeout: Optional[float] = None,
     timeout_is_recoverable: bool = False,
     log: bool = False,
@@ -144,6 +186,7 @@ async def aiterate_raw(
         reference=reference,
         hooks=tuple(hooks or []),
         cached=cached,
+        capture=capture,
         parent=ID.validate(parent.assignation) if parent else None,
         log=log,
         isHook=False,
@@ -170,6 +213,7 @@ async def acall(
     cached: bool = False,
     parent: Assign | None = None,
     log: bool = False,
+    capture: bool = False,
     structure_registry: Optional[StructureRegistry] = None,
     postman: Optional[Postman] = None,
     **kwargs: Any,  # noqa: ANN401
@@ -212,6 +256,7 @@ async def acall(
         reference=reference,
         hooks=hooks or [],
         cached=cached,
+        capture=capture,
         parent=parent,
         log=log,
         postman=postman,
@@ -233,6 +278,7 @@ async def aiterate(
     cached: bool = False,
     parent: Assign | None = None,
     log: bool = False,
+    capture: bool = False,
     structure_registry: Optional[StructureRegistry] = None,
     **kwargs: Any,  # noqa: ANN401
 ) -> AsyncGenerator[tuple[Any], None]:
@@ -274,13 +320,17 @@ async def aiterate(
         reference=reference,
         hooks=hooks or [],
         cached=cached,
+        capture=capture,
         parent=parent,
         log=log,
     ):
-        assert i.returns, "YIELD event must have returns"
-        yield await aexpand_returns(
-            action, i.returns, structure_registry=structure_registry
+        returns = await aexpand_returns(
+            action, i, structure_registry=structure_registry
         )
+        if len(returns) == 1:
+            yield returns[0]
+        else:
+            yield returns
 
 
 def call(
