@@ -18,11 +18,13 @@ import re
 
 
 ActionHash = str
-InstanceId = str
+InstanceID = str
 QString = str
 
 ValueMap = Dict[str, Any]
 
+ValidatorFunctionCoercible = str
+SearchQueryCoercible = str | DocumentNode
 
 Args = Dict[str, Any]
 
@@ -93,10 +95,14 @@ class ValidatorFunction(str):
         return core_schema.no_info_after_validator_function(cls.validate, handler(str))
 
     @classmethod
-    def validate(cls, v: str) -> "ValidatorFunction":
+    def validate(cls, v: ValidatorFunctionCoercible) -> "ValidatorFunction":
         """Validate the validator function"""
 
-        if not (v.startswith("(") or ("=>" not in v)):
+        v = str(v).strip()
+        if not v:
+            raise ValueError("ValidatorFunction cannot be empty")
+
+        if (not v.startswith("(")) or ("=>" not in v):
             raise ValueError(
                 "ValidatorFunction must be an arrow function or block function"
             )
@@ -110,7 +116,7 @@ class ValidatorFunction(str):
             if not args:
                 raise ValueError("Function must have at least one argument")
 
-        return v
+        return cls(v)
 
     def retrieve_args(self) -> list[str]:
         """Retrieve the arguments of the validator function"""
@@ -162,9 +168,9 @@ class SearchQuery(str):
     the dependencies of the widget.
     """
 
-    def __get__(self, instance, owner) -> "SearchQuery": ...
+    def __get__(self, instance, owner) -> "SearchQuery": ...  # type: ignore  # noqa: ANN001, ANN401, D105
 
-    def __set__(self, instance, value: "SearchQueryCoercible") -> None: ...
+    def __set__(self, instance, value: "SearchQueryCoercible") -> None: ...  # type: ignore  # noqa: ANN001, ANN401, D105
 
     @classmethod
     def __get_pydantic_core_schema__(  # noqa: D105
@@ -176,7 +182,7 @@ class SearchQuery(str):
         return core_schema.no_info_after_validator_function(cls.validate, handler(str))
 
     @classmethod
-    def validate(cls, v: Union[str, DocumentNode]) -> "SearchQuery":
+    def validate(cls, v: SearchQueryCoercible) -> "SearchQuery":
         """Validate the search query"""
         if not isinstance(v, str) and not isinstance(v, DocumentNode):  # type: ignore
             raise ValueError(
@@ -261,6 +267,3 @@ class SearchQuery(str):
             )
 
         return SearchQuery(print_ast(v))
-
-
-SearchQueryCoercible = str | SearchQuery | DocumentNode
