@@ -117,6 +117,9 @@ async def ashrink_arg(
                 ]
             )
 
+        if port.kind == PortKind.FLOAT:
+            return float(value) if value is not None else None
+
         if port.kind == PortKind.INT:
             return int(value) if value is not None else None
 
